@@ -32,9 +32,11 @@
 #include <QList>
 #include <QPointer>
 #include <QUrl>
+#include <QVector>
 
 typedef KIO::FileUndoManager::CommandType CommandType;
 
+class DolphinBookmarkHandler;
 class DolphinViewActionHandler;
 class DolphinSettingsDialog;
 class DolphinViewContainer;
@@ -44,6 +46,7 @@ class KFileItem;
 class KFileItemList;
 class KJob;
 class KNewFileMenu;
+class KHelpMenu;
 class QToolButton;
 class QIcon;
 class PlacesPanel;
@@ -71,6 +74,11 @@ public:
      */
     DolphinViewContainer* activeViewContainer() const;
 
+    /**
+     * Returns view container for all tabs
+     */
+    QVector<DolphinViewContainer*> viewContainers() const;
+
     /**
      * Opens each directory in \p dirs in a separate tab. If \a splitView is set,
      * 2 directories are collected within one tab.
@@ -94,6 +102,39 @@ public:
     void setTabsToHomeIfMountPathOpen(const QString& mountPath);
 
 public slots:
+    /**
+     * Opens each directory in \p dirs in a separate tab. If \a splitView is set,
+     * 2 directories are collected within one tab.
+     * \pre \a dirs must contain at least one url.
+     *
+     * @note this function is overloaded so that it is callable via DBus.
+     */
+    void openDirectories(const QStringList &dirs, bool splitView);
+
+    /**
+     * Opens the directories which contain the files \p files and selects all files.
+     * If \a splitView is set, 2 directories are collected within one tab.
+     * \pre \a files must contain at least one url.
+     *
+     * @note this is overloaded so that this function is callable via DBus.
+     */
+    void openFiles(const QStringList &files, bool splitView);
+
+    /**
+     * Tries to raise/activate the Dolphin window.
+     */
+    void activateWindow();
+
+    /**
+     * Determines if a URL is open in any tab.
+     * @note Use of QString instead of QUrl is required to be callable via DBus.
+     *
+     * @param url URL to look for
+     * @returns true if url is currently open in a tab, false otherwise.
+     */
+    bool isUrlOpen(const QString &url);
+
+
     /**
      * Pastes the clipboard data into the currently selected folder
      * of the active view. If not exactly one folder is selected,
@@ -118,6 +159,16 @@ public slots:
     /** Stores all settings and quits Dolphin. */
     void quit();
 
+    /**
+     * Opens a new tab and places it after the current tab
+     */
+    void openNewTabAfterCurrentTab(const QUrl& url);
+
+    /**
+     * Opens a new tab and places it as the last tab
+     */
+    void openNewTabAfterLastTab(const QUrl& url);
+
 signals:
     /**
      * Is sent if the selection of the currently active view has
@@ -155,6 +206,11 @@ protected:
     /** @see KMainWindow::readProperties() */
     void readProperties(const KConfigGroup& group) override;
 
+    /** Handles QWhatsThisClickedEvent and passes all others on. */
+    bool event(QEvent* event) override;
+    /** Handles QWhatsThisClickedEvent and passes all others on. */
+    bool eventFilter(QObject*, QEvent*) override;
+
 private slots:
     /**
      * Refreshes the views of the main window by recreating them according to
@@ -330,16 +386,6 @@ private slots:
      */
     void openNewTab(const QUrl& url, DolphinTabWidget::TabPlacement tabPlacement);
 
-    /**
-     * Opens a new tab and places it after the current tab
-     */
-    void openNewTabAfterCurrentTab(const QUrl& url);
-
-    /**
-     * Opens a new tab and places it as the last tab
-     */
-    void openNewTabAfterLastTab(const QUrl& url);
-
     /**
      * Opens the selected folder in a new tab.
      */
@@ -456,8 +502,16 @@ private slots:
     void slotToolBarActionMiddleClicked(QAction *action);
 
 private:
+    /**
+     * Sets up the various menus and actions and connects them.
+     */
     void setupActions();
+
+    /**
+     * Sets up the dock widgets and their panels.
+     */
     void setupDockWidgets();
+
     void updateEditActions();
     void updateViewActions();
     void updateGoActions();
@@ -501,6 +555,9 @@ private:
                            QAction* dockAction,
                            const QString& actionName);
 
+    /** Adds "What's This?" texts to many widgets and StandardActions. */
+    void setupWhatsThis();
+
 private:
     /**
      * Implements a custom error handling for the undo manager. This
@@ -516,12 +573,14 @@ private:
     };
 
     KNewFileMenu* m_newFileMenu;
+    KHelpMenu* m_helpMenu;
     DolphinTabWidget* m_tabWidget;
     DolphinViewContainer* m_activeViewContainer;
 
     DolphinViewActionHandler* m_actionHandler;
     DolphinRemoteEncoding* m_remoteEncoding;
     QPointer<DolphinSettingsDialog> m_settingsDialog;
+    DolphinBookmarkHandler* m_bookmarkHandler;
 
     // Members for the toolbar menu that is shown when the menubar is hidden:
     QToolButton* m_controlButton;
