@@ -105,9 +105,7 @@ void FoldersPanel::rename(const KFileItem& item)
         m_controller->view()->editRole(index, "text");
     } else {
         RenameDialog* dialog = new RenameDialog(this, KFileItemList() << item);
-        dialog->show();
-        dialog->raise();
-        dialog->activateWindow();
+        dialog->open();
     }
 }
 
@@ -180,7 +178,7 @@ void FoldersPanel::showEvent(QShowEvent* event)
         container->setEnabledFrame(false);
 
         QVBoxLayout* layout = new QVBoxLayout(this);
-        layout->setMargin(0);
+        layout->setContentsMargins(0, 0, 0, 0);
         layout->addWidget(container);
     }
 
@@ -216,12 +214,10 @@ void FoldersPanel::slotItemMiddleClicked(int index)
 
 void FoldersPanel::slotItemContextMenuRequested(int index, const QPointF& pos)
 {
-    Q_UNUSED(pos);
-
     const KFileItem fileItem = m_model->fileItem(index);
 
     QPointer<TreeViewContextMenu> contextMenu = new TreeViewContextMenu(this, fileItem);
-    contextMenu.data()->open();
+    contextMenu.data()->open(pos.toPoint());
     if (contextMenu.data()) {
         delete contextMenu.data();
     }
@@ -229,10 +225,8 @@ void FoldersPanel::slotItemContextMenuRequested(int index, const QPointF& pos)
 
 void FoldersPanel::slotViewContextMenuRequested(const QPointF& pos)
 {
-    Q_UNUSED(pos);
-
     QPointer<TreeViewContextMenu> contextMenu = new TreeViewContextMenu(this, KFileItem());
-    contextMenu.data()->open();
+    contextMenu.data()->open(pos.toPoint());
     if (contextMenu.data()) {
         delete contextMenu.data();
     }
